Examples
========

Here you can find a number of examples showing you what is possible!


.. toctree::
   :maxdepth: 2

   brick.rst
   checkerboard.rst


How To...
=========

.. toctree::
   :maxdepth: 2

   invert-color.rst
